.. _pyramid_tm_api:

:mod:`pyramid_tm` API
---------------------------

.. automodule:: pyramid_tm

.. autofunction:: includeme

.. autofunction:: is_tm_active

.. autofunction:: default_commit_veto

.. autofunction:: tm_tween_factory

.. autofunction:: create_tm

.. autofunction:: explicit_manager

.. autoclass:: TMActivePredicate
